@@ -41,9 +41,6 @@ require 5.005_62;
 use strict;
 use attributes qw(get reftype);
 #use warnings; --- NOT HERE because the eval in execute will complain!
-use vars qw($VERSION $BUILD);
-$VERSION = "2.3-1";
-$BUILD = 'Tuesday September 20 14:06:05 BST 2005';
 
 # ----------------------------------------------------------------------------------------------------
 {
@@ -747,7 +744,7 @@ $BUILD = 'Tuesday September 20 14:06:05 BST 2005';
 		$self->addBar;
 		$self->addComment("Generated By: @{[ $self->PARAM->VERSION ]}");
 		$self->addComment("            : http://sourceforge.net/projects/pequel/");
-		$self->addComment("Script Name : @{[ $self->PARAM->properties('script_name') ]}");
+		$self->addComment("Script Name : @{[ $self->PARAM->getscriptname() ]}");
 		$self->addComment("Created On  : @{[ '' . localtime() ]}");
 		$self->addComment("Perl Version: @{[ $^X . ' ' . sprintf(qq{%vd}, $^V) . ' on ' . $^O ]}");
 		$self->addComment("For         : @{[ getlogin() || '' ]}");
